16.11. cdist-type__ccollect_source(7) — cdist 4.10.11 documentation

# 16.11. cdist-type__ccollect_source(7)

## 16.11.1. NAME

cdist-type__ccollect_source - Manage ccollect sources

## 16.11.2. DESCRIPTION

This cdist type allows you to create or delete ccollect sources.

## 16.11.3. REQUIRED PARAMETERS

source
  The source from which to backup
destination
  The destination directory

## 16.11.4. OPTIONAL PARAMETERS

state
  'present' or 'absent', defaults to 'present'
ccollectconf
  The CCOLLECT_CONF directory. Defaults to /etc/ccollect.

## 16.11.5. OPTIONAL MULTIPLE PARAMETERS

exclude
  Paths to exclude of backup

## 16.11.6. BOOLEAN PARAMETERS

verbose
  Whether to report backup verbosely
create-destination
  Create the directory specified in the destination parameter on the remote host

## 16.11.7. EXAMPLES

    __ccollect_source doc.ungleich.ch \
        --source doc.ungleich.ch:/ \
        --destination /backup/doc.ungleich.ch \
        --exclude '/proc/*' --exclude '/sys/*' \
        --verbose

    __ccollect_source doc.ungleich.ch \
        --source doc.ungleich.ch:/ \
        --destination /backup/doc.ungleich.ch \
        --exclude '/proc/*' --exclude '/sys/*' \
        --verbose \
        --create-destination

## 16.11.8. SEE ALSO

ccollect(1)

## 16.11.9. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.11.10. COPYING

Copyright (C) 2014 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.